@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.4.6
+# @version 2.5.0
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -22,8 +22,6 @@ import shutil
 import framework
 
 class Lapack(framework.Framework):
-    lapackurl = "http://www.netlib.org/lapack/lapack.tgz"
-
     """ This class takes care of the LAPACK installation. """
     def __init__(self, config, plasma):
         print "\n","="*40
@@ -35,6 +33,8 @@ class Lapack(framework.Framework):
         self.downcmd    = plasma.downcmd
         self.prefix     = plasma.prefix
         self.plasma     = plasma
+        self.lapversion = plasma.lapversion
+        self.lapackurl  = "http://www.netlib.org/lapack/"+self.lapversion+".tgz"
 
         if self.downlapack == 2:
             self.down_install_lapack()
@@ -189,20 +189,20 @@ The reference LAPACK library is being installed.
 
         # unzip and untar
         print 'Unzip and untar reference BLAS...',
-        comm = 'gunzip -f lapack.tgz'
+        comm = 'gunzip -f '+self.lapversion+'.tgz'
         (output, error, retz) = runShellCommand(comm)
         if retz:
-            print '\n\nLAPACK: cannot unzip lapack.tgz'
+            print '\n\nLAPACK: cannot unzip '+self.lapversion+'.tgz'
             print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
             sys.exit()
 
-        comm = 'tar xf lapack.tar'
+        comm = 'tar xf '+self.lapversion+'.tar'
         (output, error, retz) = runShellCommand(comm)
         if retz:
-            print '\n\nLAPACK: cannot untar lapack.tgz'
+            print '\n\nLAPACK: cannot untar '+self.lapversion+'.tar'
             print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
             sys.exit()
-        os.remove('lapack.tar')
+        os.remove(self.lapversion+'.tar')
         print 'done'
 
 #         # Overwrite [sd]lamch.f
@@ -219,7 +219,7 @@ The reference LAPACK library is being installed.
 # -*- Makefile generated by PLASMA installer -*-
 ####################################################################
 #  LAPACK make include file.                                       #
-#  LAPACK, Version 3.4.0                                           #
+#  LAPACK, Version """+self.lapversion+""""                                           #
 #  April 2012                                                      #
 ####################################################################
 #
