@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.4.6
+# @version 2.5.0
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -22,7 +22,6 @@ import shutil
 import framework
 
 class Lapcwrapper(framework.Framework):
-    lapackurl = "http://www.netlib.org/lapack/lapack.tgz"
 
     """ This class takes care of the LAPACK C interface installation. """
     def __init__(self, config, plasma):
@@ -36,6 +35,8 @@ class Lapcwrapper(framework.Framework):
         self.mangling = plasma.mangling
         self.prefix   = plasma.prefix
         self.plasma   = plasma
+        self.lapversion = plasma.lapversion
+        self.lapackurl  = "http://www.netlib.org/lapack/"+self.lapversion+".tgz"
 
         if self.downlapc == 2:
             self.down_install_lapc()
@@ -138,25 +139,25 @@ The reference LAPACK C interface is being installed.
             # otherwise download it
             if not os.path.isfile(os.path.join(os.getcwd(),getURLName(self.lapackurl))):
                 print "Downloading reference LAPACK C interface...",
-                downloader(self.lapcurl,self.downcmd)
+                downloader(self.lapackurl,self.downcmd)
                 print "done"
-            
+
             # unzip and untar
             print 'Unzip and untar reference LAPACK C interface...',
-            comm = 'gunzip -f lapack.tgz'
+            comm = 'gunzip -f '+self.lapversion+'.tgz'
             (output, error, retz) = runShellCommand(comm)
             if retz:
-                print '\n\nLAPCWRAPPER: cannot unzip lapack.tgz'
+                print '\n\nLAPCWRAPPER: cannot unzip '+self.lapversion+'.tgz'
                 print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
                 sys.exit()
-            
-            comm = 'tar xf lapack.tar'
+
+            comm = 'tar xf '+self.lapversion+'.tar'
             (output, error, retz) = runShellCommand(comm)
             if retz:
-                print '\n\nLAPCWRAPPER: cannot untar lapack.tar'
+                print '\n\nLAPCWRAPPER: cannot untar '+self.lapversion+'.tar'
                 print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
                 sys.exit()
-            os.remove('lapack.tar')
+            os.remove(self.lapversion+'.tar')
             print 'done'
 
         # change to LAPACK C interface dir
